# coding: utf-8

"""
    IoT服务

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_iot_service.configuration import Configuration


class ReadNodeInput(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'opc_flag': 'str',
        'node': 'str',
        'data_type': 'int'
    }

    attribute_map = {
        'opc_flag': 'opcFlag',
        'node': 'node',
        'data_type': 'dataType'
    }

    def __init__(self, opc_flag=None, node=None, data_type=None, local_vars_configuration=None):  # noqa: E501
        """ReadNodeInput - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._opc_flag = None
        self._node = None
        self._data_type = None
        self.discriminator = None

        self.opc_flag = opc_flag
        self.node = node
        self.data_type = data_type

    @property
    def opc_flag(self):
        """Gets the opc_flag of this ReadNodeInput.  # noqa: E501

        opc server 标识 mark  # noqa: E501

        :return: The opc_flag of this ReadNodeInput.  # noqa: E501
        :rtype: str
        """
        return self._opc_flag

    @opc_flag.setter
    def opc_flag(self, opc_flag):
        """Sets the opc_flag of this ReadNodeInput.

        opc server 标识 mark  # noqa: E501

        :param opc_flag: The opc_flag of this ReadNodeInput.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and opc_flag is None:  # noqa: E501
            raise ValueError("Invalid value for `opc_flag`, must not be `None`")  # noqa: E501

        self._opc_flag = opc_flag

    @property
    def node(self):
        """Gets the node of this ReadNodeInput.  # noqa: E501

        节点 node  # noqa: E501

        :return: The node of this ReadNodeInput.  # noqa: E501
        :rtype: str
        """
        return self._node

    @node.setter
    def node(self, node):
        """Sets the node of this ReadNodeInput.

        节点 node  # noqa: E501

        :param node: The node of this ReadNodeInput.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and node is None:  # noqa: E501
            raise ValueError("Invalid value for `node`, must not be `None`")  # noqa: E501

        self._node = node

    @property
    def data_type(self):
        """Gets the data_type of this ReadNodeInput.  # noqa: E501

        0-BoolValue 1-DateTimeValue 2-DblValue 3-LongValue 4-StrValue 5-FloatValue 6-UInt32Value 7-UInt16Value 8-Int32Value 9-Int16Value   # noqa: E501

        :return: The data_type of this ReadNodeInput.  # noqa: E501
        :rtype: int
        """
        return self._data_type

    @data_type.setter
    def data_type(self, data_type):
        """Sets the data_type of this ReadNodeInput.

        0-BoolValue 1-DateTimeValue 2-DblValue 3-LongValue 4-StrValue 5-FloatValue 6-UInt32Value 7-UInt16Value 8-Int32Value 9-Int16Value   # noqa: E501

        :param data_type: The data_type of this ReadNodeInput.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and data_type is None:  # noqa: E501
            raise ValueError("Invalid value for `data_type`, must not be `None`")  # noqa: E501
        allowed_values = [0, 1, 2, 3, 4, 5, 6, 7, 8, 9]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and data_type not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `data_type` ({0}), must be one of {1}"  # noqa: E501
                .format(data_type, allowed_values)
            )

        self._data_type = data_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ReadNodeInput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ReadNodeInput):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    digital-twin-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_digital_twin_service.configuration import Configuration


class Coordinate(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'x': 'float',
        'y': 'float',
        'z': 'float',
        'm': 'float',
        'coordinate_value': 'Coordinate',
        'is_valid': 'bool'
    }

    attribute_map = {
        'x': 'x',
        'y': 'y',
        'z': 'z',
        'm': 'm',
        'coordinate_value': 'coordinateValue',
        'is_valid': 'isValid'
    }

    def __init__(self, x=None, y=None, z=None, m=None, coordinate_value=None, is_valid=None, local_vars_configuration=None):  # noqa: E501
        """Coordinate - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._x = None
        self._y = None
        self._z = None
        self._m = None
        self._coordinate_value = None
        self._is_valid = None
        self.discriminator = None

        if x is not None:
            self.x = x
        if y is not None:
            self.y = y
        if z is not None:
            self.z = z
        if m is not None:
            self.m = m
        if coordinate_value is not None:
            self.coordinate_value = coordinate_value
        if is_valid is not None:
            self.is_valid = is_valid

    @property
    def x(self):
        """Gets the x of this Coordinate.  # noqa: E501


        :return: The x of this Coordinate.  # noqa: E501
        :rtype: float
        """
        return self._x

    @x.setter
    def x(self, x):
        """Sets the x of this Coordinate.


        :param x: The x of this Coordinate.  # noqa: E501
        :type: float
        """

        self._x = x

    @property
    def y(self):
        """Gets the y of this Coordinate.  # noqa: E501


        :return: The y of this Coordinate.  # noqa: E501
        :rtype: float
        """
        return self._y

    @y.setter
    def y(self, y):
        """Sets the y of this Coordinate.


        :param y: The y of this Coordinate.  # noqa: E501
        :type: float
        """

        self._y = y

    @property
    def z(self):
        """Gets the z of this Coordinate.  # noqa: E501


        :return: The z of this Coordinate.  # noqa: E501
        :rtype: float
        """
        return self._z

    @z.setter
    def z(self, z):
        """Sets the z of this Coordinate.


        :param z: The z of this Coordinate.  # noqa: E501
        :type: float
        """

        self._z = z

    @property
    def m(self):
        """Gets the m of this Coordinate.  # noqa: E501


        :return: The m of this Coordinate.  # noqa: E501
        :rtype: float
        """
        return self._m

    @m.setter
    def m(self, m):
        """Sets the m of this Coordinate.


        :param m: The m of this Coordinate.  # noqa: E501
        :type: float
        """

        self._m = m

    @property
    def coordinate_value(self):
        """Gets the coordinate_value of this Coordinate.  # noqa: E501


        :return: The coordinate_value of this Coordinate.  # noqa: E501
        :rtype: Coordinate
        """
        return self._coordinate_value

    @coordinate_value.setter
    def coordinate_value(self, coordinate_value):
        """Sets the coordinate_value of this Coordinate.


        :param coordinate_value: The coordinate_value of this Coordinate.  # noqa: E501
        :type: Coordinate
        """

        self._coordinate_value = coordinate_value

    @property
    def is_valid(self):
        """Gets the is_valid of this Coordinate.  # noqa: E501


        :return: The is_valid of this Coordinate.  # noqa: E501
        :rtype: bool
        """
        return self._is_valid

    @is_valid.setter
    def is_valid(self, is_valid):
        """Sets the is_valid of this Coordinate.


        :param is_valid: The is_valid of this Coordinate.  # noqa: E501
        :type: bool
        """

        self._is_valid = is_valid

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Coordinate):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Coordinate):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    result-analysis-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_result_analysis_service.configuration import Configuration


class ModelResultRiverWqInput(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'scenario_id': 'str',
        'wq_item': 'str',
        'frequency': 'int',
        'start_time': 'datetime',
        'end_time': 'datetime'
    }

    attribute_map = {
        'scenario_id': 'scenarioId',
        'wq_item': 'wqItem',
        'frequency': 'frequency',
        'start_time': 'startTime',
        'end_time': 'endTime'
    }

    def __init__(self, scenario_id=None, wq_item=None, frequency=None, start_time=None, end_time=None, local_vars_configuration=None):  # noqa: E501
        """ModelResultRiverWqInput - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._scenario_id = None
        self._wq_item = None
        self._frequency = None
        self._start_time = None
        self._end_time = None
        self.discriminator = None

        self.scenario_id = scenario_id
        self.wq_item = wq_item
        if frequency is not None:
            self.frequency = frequency
        if start_time is not None:
            self.start_time = start_time
        if end_time is not None:
            self.end_time = end_time

    @property
    def scenario_id(self):
        """Gets the scenario_id of this ModelResultRiverWqInput.  # noqa: E501

        方案id scenario id  # noqa: E501

        :return: The scenario_id of this ModelResultRiverWqInput.  # noqa: E501
        :rtype: str
        """
        return self._scenario_id

    @scenario_id.setter
    def scenario_id(self, scenario_id):
        """Sets the scenario_id of this ModelResultRiverWqInput.

        方案id scenario id  # noqa: E501

        :param scenario_id: The scenario_id of this ModelResultRiverWqInput.  # noqa: E501
        :type: str
        """

        self._scenario_id = scenario_id

    @property
    def wq_item(self):
        """Gets the wq_item of this ModelResultRiverWqInput.  # noqa: E501

        水质 water quality  # noqa: E501

        :return: The wq_item of this ModelResultRiverWqInput.  # noqa: E501
        :rtype: str
        """
        return self._wq_item

    @wq_item.setter
    def wq_item(self, wq_item):
        """Sets the wq_item of this ModelResultRiverWqInput.

        水质 water quality  # noqa: E501

        :param wq_item: The wq_item of this ModelResultRiverWqInput.  # noqa: E501
        :type: str
        """

        self._wq_item = wq_item

    @property
    def frequency(self):
        """Gets the frequency of this ModelResultRiverWqInput.  # noqa: E501

        频率 frequency  # noqa: E501

        :return: The frequency of this ModelResultRiverWqInput.  # noqa: E501
        :rtype: int
        """
        return self._frequency

    @frequency.setter
    def frequency(self, frequency):
        """Sets the frequency of this ModelResultRiverWqInput.

        频率 frequency  # noqa: E501

        :param frequency: The frequency of this ModelResultRiverWqInput.  # noqa: E501
        :type: int
        """

        self._frequency = frequency

    @property
    def start_time(self):
        """Gets the start_time of this ModelResultRiverWqInput.  # noqa: E501

        开始时间 start time  # noqa: E501

        :return: The start_time of this ModelResultRiverWqInput.  # noqa: E501
        :rtype: datetime
        """
        return self._start_time

    @start_time.setter
    def start_time(self, start_time):
        """Sets the start_time of this ModelResultRiverWqInput.

        开始时间 start time  # noqa: E501

        :param start_time: The start_time of this ModelResultRiverWqInput.  # noqa: E501
        :type: datetime
        """

        self._start_time = start_time

    @property
    def end_time(self):
        """Gets the end_time of this ModelResultRiverWqInput.  # noqa: E501

        结束时间 end time  # noqa: E501

        :return: The end_time of this ModelResultRiverWqInput.  # noqa: E501
        :rtype: datetime
        """
        return self._end_time

    @end_time.setter
    def end_time(self, end_time):
        """Sets the end_time of this ModelResultRiverWqInput.

        结束时间 end time  # noqa: E501

        :param end_time: The end_time of this ModelResultRiverWqInput.  # noqa: E501
        :type: datetime
        """

        self._end_time = end_time

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ModelResultRiverWqInput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ModelResultRiverWqInput):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    identity-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from dhicn_identity_service.api_client import ApiClient
from dhicn_identity_service.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class MicroServicesManagerApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def api_app_micro_services_manager_id_micro_service_by_id_get(self, id, **kwargs):  # noqa: E501
        """通过微服务Id获取微服务 Get microservice through microservice ID  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_app_micro_services_manager_id_micro_service_by_id_get(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str id: 微服务ID micro service id (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: MicroServiceOutput
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_app_micro_services_manager_id_micro_service_by_id_get_with_http_info(id, **kwargs)  # noqa: E501

    def api_app_micro_services_manager_id_micro_service_by_id_get_with_http_info(self, id, **kwargs):  # noqa: E501
        """通过微服务Id获取微服务 Get microservice through microservice ID  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_app_micro_services_manager_id_micro_service_by_id_get_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str id: 微服务ID micro service id (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(MicroServiceOutput, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_app_micro_services_manager_id_micro_service_by_id_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in local_var_params or  # noqa: E501
                                                        local_var_params['id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `id` when calling `api_app_micro_services_manager_id_micro_service_by_id_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in local_var_params:
            path_params['id'] = local_var_params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/app/microServicesManager/{id}/microServiceById', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='MicroServiceOutput',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_app_micro_services_manager_id_role_permissions_by_id_get(self, id, **kwargs):  # noqa: E501
        """通过d获取角色权限 Get role permissions through ID  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_app_micro_services_manager_id_role_permissions_by_id_get(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str id: 角色权限ID role permission id (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: GetRolePermissionsOutput
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_app_micro_services_manager_id_role_permissions_by_id_get_with_http_info(id, **kwargs)  # noqa: E501

    def api_app_micro_services_manager_id_role_permissions_by_id_get_with_http_info(self, id, **kwargs):  # noqa: E501
        """通过d获取角色权限 Get role permissions through ID  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_app_micro_services_manager_id_role_permissions_by_id_get_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str id: 角色权限ID role permission id (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(GetRolePermissionsOutput, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_app_micro_services_manager_id_role_permissions_by_id_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in local_var_params or  # noqa: E501
                                                        local_var_params['id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `id` when calling `api_app_micro_services_manager_id_role_permissions_by_id_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in local_var_params:
            path_params['id'] = local_var_params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/app/microServicesManager/{id}/rolePermissionsById', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GetRolePermissionsOutput',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_app_micro_services_manager_micro_service_delete(self, ids, **kwargs):  # noqa: E501
        """删除微服务 Delete micro service  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_app_micro_services_manager_micro_service_delete(ids, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[str] ids: ID列表 ids (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_app_micro_services_manager_micro_service_delete_with_http_info(ids, **kwargs)  # noqa: E501

    def api_app_micro_services_manager_micro_service_delete_with_http_info(self, ids, **kwargs):  # noqa: E501
        """删除微服务 Delete micro service  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_app_micro_services_manager_micro_service_delete_with_http_info(ids, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[str] ids: ID列表 ids (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'ids'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_app_micro_services_manager_micro_service_delete" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'ids' is set
        if self.api_client.client_side_validation and ('ids' not in local_var_params or  # noqa: E501
                                                        local_var_params['ids'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `ids` when calling `api_app_micro_services_manager_micro_service_delete`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'ids' in local_var_params and local_var_params['ids'] is not None:  # noqa: E501
            query_params.append(('Ids', local_var_params['ids']))  # noqa: E501
            collection_formats['Ids'] = 'multi'  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/app/microServicesManager/microService', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_app_micro_services_manager_micro_service_post(self, **kwargs):  # noqa: E501
        """添加微服务 Add microservices  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_app_micro_services_manager_micro_service_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param AddMicroServiceInput add_micro_service_input:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_app_micro_services_manager_micro_service_post_with_http_info(**kwargs)  # noqa: E501

    def api_app_micro_services_manager_micro_service_post_with_http_info(self, **kwargs):  # noqa: E501
        """添加微服务 Add microservices  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_app_micro_services_manager_micro_service_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param AddMicroServiceInput add_micro_service_input:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'add_micro_service_input'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_app_micro_services_manager_micro_service_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'add_micro_service_input' in local_var_params:
            body_params = local_var_params['add_micro_service_input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/app/microServicesManager/microService', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_app_micro_services_manager_micro_service_put(self, **kwargs):  # noqa: E501
        """更新微服务 Update microservices  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_app_micro_services_manager_micro_service_put(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param UpdateMicroServiceInput update_micro_service_input:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_app_micro_services_manager_micro_service_put_with_http_info(**kwargs)  # noqa: E501

    def api_app_micro_services_manager_micro_service_put_with_http_info(self, **kwargs):  # noqa: E501
        """更新微服务 Update microservices  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_app_micro_services_manager_micro_service_put_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param UpdateMicroServiceInput update_micro_service_input:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'update_micro_service_input'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_app_micro_services_manager_micro_service_put" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'update_micro_service_input' in local_var_params:
            body_params = local_var_params['update_micro_service_input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/app/microServicesManager/microService', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_app_micro_services_manager_micro_services_get(self, **kwargs):  # noqa: E501
        """获取微服务 Get micro services  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_app_micro_services_manager_micro_services_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str keywords: 根据关键字检索 query key words
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[MicroServiceOutput]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_app_micro_services_manager_micro_services_get_with_http_info(**kwargs)  # noqa: E501

    def api_app_micro_services_manager_micro_services_get_with_http_info(self, **kwargs):  # noqa: E501
        """获取微服务 Get micro services  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_app_micro_services_manager_micro_services_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str keywords: 根据关键字检索 query key words
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[MicroServiceOutput], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'keywords'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_app_micro_services_manager_micro_services_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'keywords' in local_var_params and local_var_params['keywords'] is not None:  # noqa: E501
            query_params.append(('Keywords', local_var_params['keywords']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/app/microServicesManager/microServices', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[MicroServiceOutput]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_app_micro_services_manager_role_permissions_delete(self, ids, **kwargs):  # noqa: E501
        """删除角色权限 Delete role permissions  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_app_micro_services_manager_role_permissions_delete(ids, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[str] ids: ID列表 ids (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_app_micro_services_manager_role_permissions_delete_with_http_info(ids, **kwargs)  # noqa: E501

    def api_app_micro_services_manager_role_permissions_delete_with_http_info(self, ids, **kwargs):  # noqa: E501
        """删除角色权限 Delete role permissions  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_app_micro_services_manager_role_permissions_delete_with_http_info(ids, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[str] ids: ID列表 ids (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'ids'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_app_micro_services_manager_role_permissions_delete" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'ids' is set
        if self.api_client.client_side_validation and ('ids' not in local_var_params or  # noqa: E501
                                                        local_var_params['ids'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `ids` when calling `api_app_micro_services_manager_role_permissions_delete`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'ids' in local_var_params and local_var_params['ids'] is not None:  # noqa: E501
            query_params.append(('Ids', local_var_params['ids']))  # noqa: E501
            collection_formats['Ids'] = 'multi'  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/app/microServicesManager/rolePermissions', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_app_micro_services_manager_role_permissions_get(self, **kwargs):  # noqa: E501
        """获取角色权限 Get role permissions  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_app_micro_services_manager_role_permissions_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str tenant_id: 租户Id tenant id
        :param str role: 角色 role name
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[GetRolePermissionsOutput]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_app_micro_services_manager_role_permissions_get_with_http_info(**kwargs)  # noqa: E501

    def api_app_micro_services_manager_role_permissions_get_with_http_info(self, **kwargs):  # noqa: E501
        """获取角色权限 Get role permissions  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_app_micro_services_manager_role_permissions_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str tenant_id: 租户Id tenant id
        :param str role: 角色 role name
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[GetRolePermissionsOutput], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'tenant_id',
            'role'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_app_micro_services_manager_role_permissions_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'tenant_id' in local_var_params and local_var_params['tenant_id'] is not None:  # noqa: E501
            query_params.append(('TenantId', local_var_params['tenant_id']))  # noqa: E501
        if 'role' in local_var_params and local_var_params['role'] is not None:  # noqa: E501
            query_params.append(('Role', local_var_params['role']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/app/microServicesManager/rolePermissions', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[GetRolePermissionsOutput]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_app_micro_services_manager_role_permissions_post(self, **kwargs):  # noqa: E501
        """添加角色权限 Add role permissions  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_app_micro_services_manager_role_permissions_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param AddRolePermissionsInput add_role_permissions_input:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_app_micro_services_manager_role_permissions_post_with_http_info(**kwargs)  # noqa: E501

    def api_app_micro_services_manager_role_permissions_post_with_http_info(self, **kwargs):  # noqa: E501
        """添加角色权限 Add role permissions  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_app_micro_services_manager_role_permissions_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param AddRolePermissionsInput add_role_permissions_input:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'add_role_permissions_input'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_app_micro_services_manager_role_permissions_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'add_role_permissions_input' in local_var_params:
            body_params = local_var_params['add_role_permissions_input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/app/microServicesManager/rolePermissions', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_app_micro_services_manager_role_permissions_put(self, **kwargs):  # noqa: E501
        """更新角色权限 Update role permissions  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_app_micro_services_manager_role_permissions_put(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param UpdateRolePermissionsInput update_role_permissions_input:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_app_micro_services_manager_role_permissions_put_with_http_info(**kwargs)  # noqa: E501

    def api_app_micro_services_manager_role_permissions_put_with_http_info(self, **kwargs):  # noqa: E501
        """更新角色权限 Update role permissions  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_app_micro_services_manager_role_permissions_put_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param UpdateRolePermissionsInput update_role_permissions_input:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'update_role_permissions_input'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_app_micro_services_manager_role_permissions_put" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'update_role_permissions_input' in local_var_params:
            body_params = local_var_params['update_role_permissions_input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/app/microServicesManager/rolePermissions', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from dhicn_scenario_manager_service.api.library_api import LibraryApi
from dhicn_scenario_manager_service.api.scenario_group_api import ScenarioGroupApi
from dhicn_scenario_manager_service.api.scenario_manager_api import ScenarioManagerApi



# coding: utf-8

"""
    digital-twin-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_digital_twin_service.configuration import Configuration


class RealityModelRelationOutput(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'template_id': 'str',
        'model_point_id': 'str',
        'entity_id': 'str',
        'entity_type': 'str',
        'data_type_mapping': 'list[PointDataTypeInfo]'
    }

    attribute_map = {
        'id': 'id',
        'template_id': 'templateId',
        'model_point_id': 'modelPointId',
        'entity_id': 'entityId',
        'entity_type': 'entityType',
        'data_type_mapping': 'dataTypeMapping'
    }

    def __init__(self, id=None, template_id=None, model_point_id=None, entity_id=None, entity_type=None, data_type_mapping=None, local_vars_configuration=None):  # noqa: E501
        """RealityModelRelationOutput - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._template_id = None
        self._model_point_id = None
        self._entity_id = None
        self._entity_type = None
        self._data_type_mapping = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if template_id is not None:
            self.template_id = template_id
        if model_point_id is not None:
            self.model_point_id = model_point_id
        if entity_id is not None:
            self.entity_id = entity_id
        self.entity_type = entity_type
        self.data_type_mapping = data_type_mapping

    @property
    def id(self):
        """Gets the id of this RealityModelRelationOutput.  # noqa: E501

        映射关系ID mapping relation id  # noqa: E501

        :return: The id of this RealityModelRelationOutput.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this RealityModelRelationOutput.

        映射关系ID mapping relation id  # noqa: E501

        :param id: The id of this RealityModelRelationOutput.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def template_id(self):
        """Gets the template_id of this RealityModelRelationOutput.  # noqa: E501

        模板方案ID template scenario id  # noqa: E501

        :return: The template_id of this RealityModelRelationOutput.  # noqa: E501
        :rtype: str
        """
        return self._template_id

    @template_id.setter
    def template_id(self, template_id):
        """Sets the template_id of this RealityModelRelationOutput.

        模板方案ID template scenario id  # noqa: E501

        :param template_id: The template_id of this RealityModelRelationOutput.  # noqa: E501
        :type: str
        """

        self._template_id = template_id

    @property
    def model_point_id(self):
        """Gets the model_point_id of this RealityModelRelationOutput.  # noqa: E501

        模型点位ID model point id  # noqa: E501

        :return: The model_point_id of this RealityModelRelationOutput.  # noqa: E501
        :rtype: str
        """
        return self._model_point_id

    @model_point_id.setter
    def model_point_id(self, model_point_id):
        """Sets the model_point_id of this RealityModelRelationOutput.

        模型点位ID model point id  # noqa: E501

        :param model_point_id: The model_point_id of this RealityModelRelationOutput.  # noqa: E501
        :type: str
        """

        self._model_point_id = model_point_id

    @property
    def entity_id(self):
        """Gets the entity_id of this RealityModelRelationOutput.  # noqa: E501

        资产/设备ID asset/device id  # noqa: E501

        :return: The entity_id of this RealityModelRelationOutput.  # noqa: E501
        :rtype: str
        """
        return self._entity_id

    @entity_id.setter
    def entity_id(self, entity_id):
        """Sets the entity_id of this RealityModelRelationOutput.

        资产/设备ID asset/device id  # noqa: E501

        :param entity_id: The entity_id of this RealityModelRelationOutput.  # noqa: E501
        :type: str
        """

        self._entity_id = entity_id

    @property
    def entity_type(self):
        """Gets the entity_type of this RealityModelRelationOutput.  # noqa: E501

        实体类型，资产或设备 entity type, Asset or Device  # noqa: E501

        :return: The entity_type of this RealityModelRelationOutput.  # noqa: E501
        :rtype: str
        """
        return self._entity_type

    @entity_type.setter
    def entity_type(self, entity_type):
        """Sets the entity_type of this RealityModelRelationOutput.

        实体类型，资产或设备 entity type, Asset or Device  # noqa: E501

        :param entity_type: The entity_type of this RealityModelRelationOutput.  # noqa: E501
        :type: str
        """

        self._entity_type = entity_type

    @property
    def data_type_mapping(self):
        """Gets the data_type_mapping of this RealityModelRelationOutput.  # noqa: E501

        模型点位数据类型与设备指标之间的映射关系 mapping relations of model point data type and device indicator  # noqa: E501

        :return: The data_type_mapping of this RealityModelRelationOutput.  # noqa: E501
        :rtype: list[PointDataTypeInfo]
        """
        return self._data_type_mapping

    @data_type_mapping.setter
    def data_type_mapping(self, data_type_mapping):
        """Sets the data_type_mapping of this RealityModelRelationOutput.

        模型点位数据类型与设备指标之间的映射关系 mapping relations of model point data type and device indicator  # noqa: E501

        :param data_type_mapping: The data_type_mapping of this RealityModelRelationOutput.  # noqa: E501
        :type: list[PointDataTypeInfo]
        """

        self._data_type_mapping = data_type_mapping

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RealityModelRelationOutput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, RealityModelRelationOutput):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    result-analysis-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_result_analysis_service.configuration import Configuration


class RrSummaryPerCatchment(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'catchment_id': 'str',
        'start_volume': 'float',
        'total_inflow': 'float',
        'total_losses': 'float',
        'total_runoff': 'float',
        'end_volume': 'float',
        'total_inflow_percent': 'float'
    }

    attribute_map = {
        'catchment_id': 'catchmentID',
        'start_volume': 'startVolume',
        'total_inflow': 'totalInflow',
        'total_losses': 'totalLosses',
        'total_runoff': 'totalRunoff',
        'end_volume': 'endVolume',
        'total_inflow_percent': 'totalInflowPercent'
    }

    def __init__(self, catchment_id=None, start_volume=None, total_inflow=None, total_losses=None, total_runoff=None, end_volume=None, total_inflow_percent=None, local_vars_configuration=None):  # noqa: E501
        """RrSummaryPerCatchment - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._catchment_id = None
        self._start_volume = None
        self._total_inflow = None
        self._total_losses = None
        self._total_runoff = None
        self._end_volume = None
        self._total_inflow_percent = None
        self.discriminator = None

        self.catchment_id = catchment_id
        if start_volume is not None:
            self.start_volume = start_volume
        if total_inflow is not None:
            self.total_inflow = total_inflow
        if total_losses is not None:
            self.total_losses = total_losses
        if total_runoff is not None:
            self.total_runoff = total_runoff
        if end_volume is not None:
            self.end_volume = end_volume
        if total_inflow_percent is not None:
            self.total_inflow_percent = total_inflow_percent

    @property
    def catchment_id(self):
        """Gets the catchment_id of this RrSummaryPerCatchment.  # noqa: E501

        汇水区ID catchment muid  # noqa: E501

        :return: The catchment_id of this RrSummaryPerCatchment.  # noqa: E501
        :rtype: str
        """
        return self._catchment_id

    @catchment_id.setter
    def catchment_id(self, catchment_id):
        """Sets the catchment_id of this RrSummaryPerCatchment.

        汇水区ID catchment muid  # noqa: E501

        :param catchment_id: The catchment_id of this RrSummaryPerCatchment.  # noqa: E501
        :type: str
        """

        self._catchment_id = catchment_id

    @property
    def start_volume(self):
        """Gets the start_volume of this RrSummaryPerCatchment.  # noqa: E501

        初始水量 start volume of the catchment  # noqa: E501

        :return: The start_volume of this RrSummaryPerCatchment.  # noqa: E501
        :rtype: float
        """
        return self._start_volume

    @start_volume.setter
    def start_volume(self, start_volume):
        """Sets the start_volume of this RrSummaryPerCatchment.

        初始水量 start volume of the catchment  # noqa: E501

        :param start_volume: The start_volume of this RrSummaryPerCatchment.  # noqa: E501
        :type: float
        """

        self._start_volume = start_volume

    @property
    def total_inflow(self):
        """Gets the total_inflow of this RrSummaryPerCatchment.  # noqa: E501

        总入流量 total inflow of the catchment  # noqa: E501

        :return: The total_inflow of this RrSummaryPerCatchment.  # noqa: E501
        :rtype: float
        """
        return self._total_inflow

    @total_inflow.setter
    def total_inflow(self, total_inflow):
        """Sets the total_inflow of this RrSummaryPerCatchment.

        总入流量 total inflow of the catchment  # noqa: E501

        :param total_inflow: The total_inflow of this RrSummaryPerCatchment.  # noqa: E501
        :type: float
        """

        self._total_inflow = total_inflow

    @property
    def total_losses(self):
        """Gets the total_losses of this RrSummaryPerCatchment.  # noqa: E501

        总流失量 total losses of the catchment  # noqa: E501

        :return: The total_losses of this RrSummaryPerCatchment.  # noqa: E501
        :rtype: float
        """
        return self._total_losses

    @total_losses.setter
    def total_losses(self, total_losses):
        """Sets the total_losses of this RrSummaryPerCatchment.

        总流失量 total losses of the catchment  # noqa: E501

        :param total_losses: The total_losses of this RrSummaryPerCatchment.  # noqa: E501
        :type: float
        """

        self._total_losses = total_losses

    @property
    def total_runoff(self):
        """Gets the total_runoff of this RrSummaryPerCatchment.  # noqa: E501

        总径流量 total runoff discharge of the catchment  # noqa: E501

        :return: The total_runoff of this RrSummaryPerCatchment.  # noqa: E501
        :rtype: float
        """
        return self._total_runoff

    @total_runoff.setter
    def total_runoff(self, total_runoff):
        """Sets the total_runoff of this RrSummaryPerCatchment.

        总径流量 total runoff discharge of the catchment  # noqa: E501

        :param total_runoff: The total_runoff of this RrSummaryPerCatchment.  # noqa: E501
        :type: float
        """

        self._total_runoff = total_runoff

    @property
    def end_volume(self):
        """Gets the end_volume of this RrSummaryPerCatchment.  # noqa: E501

        终止水量 end volume of the catchment  # noqa: E501

        :return: The end_volume of this RrSummaryPerCatchment.  # noqa: E501
        :rtype: float
        """
        return self._end_volume

    @end_volume.setter
    def end_volume(self, end_volume):
        """Sets the end_volume of this RrSummaryPerCatchment.

        终止水量 end volume of the catchment  # noqa: E501

        :param end_volume: The end_volume of this RrSummaryPerCatchment.  # noqa: E501
        :type: float
        """

        self._end_volume = end_volume

    @property
    def total_inflow_percent(self):
        """Gets the total_inflow_percent of this RrSummaryPerCatchment.  # noqa: E501

        占总入流量的百分比 total inflow percent of the catchment  # noqa: E501

        :return: The total_inflow_percent of this RrSummaryPerCatchment.  # noqa: E501
        :rtype: float
        """
        return self._total_inflow_percent

    @total_inflow_percent.setter
    def total_inflow_percent(self, total_inflow_percent):
        """Sets the total_inflow_percent of this RrSummaryPerCatchment.

        占总入流量的百分比 total inflow percent of the catchment  # noqa: E501

        :param total_inflow_percent: The total_inflow_percent of this RrSummaryPerCatchment.  # noqa: E501
        :type: float
        """

        self._total_inflow_percent = total_inflow_percent

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RrSummaryPerCatchment):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, RrSummaryPerCatchment):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    wwtp-paas-main-bus-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_wwtp_data_bus_service.configuration import Configuration


class QueryIndicatorStatisticOutput(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'code': 'str',
        'unit': 'str',
        'mean': 'float',
        'min': 'float',
        'max': 'float',
        'median': 'float',
        'upper_percent': 'float',
        'lower_percent': 'float'
    }

    attribute_map = {
        'code': 'code',
        'unit': 'unit',
        'mean': 'mean',
        'min': 'min',
        'max': 'max',
        'median': 'median',
        'upper_percent': 'upperPercent',
        'lower_percent': 'lowerPercent'
    }

    def __init__(self, code=None, unit=None, mean=None, min=None, max=None, median=None, upper_percent=None, lower_percent=None, local_vars_configuration=None):  # noqa: E501
        """QueryIndicatorStatisticOutput - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._code = None
        self._unit = None
        self._mean = None
        self._min = None
        self._max = None
        self._median = None
        self._upper_percent = None
        self._lower_percent = None
        self.discriminator = None

        self.code = code
        self.unit = unit
        if mean is not None:
            self.mean = mean
        if min is not None:
            self.min = min
        if max is not None:
            self.max = max
        if median is not None:
            self.median = median
        if upper_percent is not None:
            self.upper_percent = upper_percent
        if lower_percent is not None:
            self.lower_percent = lower_percent

    @property
    def code(self):
        """Gets the code of this QueryIndicatorStatisticOutput.  # noqa: E501

        指标代码 indicator code  # noqa: E501

        :return: The code of this QueryIndicatorStatisticOutput.  # noqa: E501
        :rtype: str
        """
        return self._code

    @code.setter
    def code(self, code):
        """Sets the code of this QueryIndicatorStatisticOutput.

        指标代码 indicator code  # noqa: E501

        :param code: The code of this QueryIndicatorStatisticOutput.  # noqa: E501
        :type: str
        """

        self._code = code

    @property
    def unit(self):
        """Gets the unit of this QueryIndicatorStatisticOutput.  # noqa: E501

        单位 unit  # noqa: E501

        :return: The unit of this QueryIndicatorStatisticOutput.  # noqa: E501
        :rtype: str
        """
        return self._unit

    @unit.setter
    def unit(self, unit):
        """Sets the unit of this QueryIndicatorStatisticOutput.

        单位 unit  # noqa: E501

        :param unit: The unit of this QueryIndicatorStatisticOutput.  # noqa: E501
        :type: str
        """

        self._unit = unit

    @property
    def mean(self):
        """Gets the mean of this QueryIndicatorStatisticOutput.  # noqa: E501

        平均值 average value  # noqa: E501

        :return: The mean of this QueryIndicatorStatisticOutput.  # noqa: E501
        :rtype: float
        """
        return self._mean

    @mean.setter
    def mean(self, mean):
        """Sets the mean of this QueryIndicatorStatisticOutput.

        平均值 average value  # noqa: E501

        :param mean: The mean of this QueryIndicatorStatisticOutput.  # noqa: E501
        :type: float
        """

        self._mean = mean

    @property
    def min(self):
        """Gets the min of this QueryIndicatorStatisticOutput.  # noqa: E501

        最小值 minimum value  # noqa: E501

        :return: The min of this QueryIndicatorStatisticOutput.  # noqa: E501
        :rtype: float
        """
        return self._min

    @min.setter
    def min(self, min):
        """Sets the min of this QueryIndicatorStatisticOutput.

        最小值 minimum value  # noqa: E501

        :param min: The min of this QueryIndicatorStatisticOutput.  # noqa: E501
        :type: float
        """

        self._min = min

    @property
    def max(self):
        """Gets the max of this QueryIndicatorStatisticOutput.  # noqa: E501

        最大值 maximum value  # noqa: E501

        :return: The max of this QueryIndicatorStatisticOutput.  # noqa: E501
        :rtype: float
        """
        return self._max

    @max.setter
    def max(self, max):
        """Sets the max of this QueryIndicatorStatisticOutput.

        最大值 maximum value  # noqa: E501

        :param max: The max of this QueryIndicatorStatisticOutput.  # noqa: E501
        :type: float
        """

        self._max = max

    @property
    def median(self):
        """Gets the median of this QueryIndicatorStatisticOutput.  # noqa: E501

        中位数 median value  # noqa: E501

        :return: The median of this QueryIndicatorStatisticOutput.  # noqa: E501
        :rtype: float
        """
        return self._median

    @median.setter
    def median(self, median):
        """Sets the median of this QueryIndicatorStatisticOutput.

        中位数 median value  # noqa: E501

        :param median: The median of this QueryIndicatorStatisticOutput.  # noqa: E501
        :type: float
        """

        self._median = median

    @property
    def upper_percent(self):
        """Gets the upper_percent of this QueryIndicatorStatisticOutput.  # noqa: E501

        上百分位 upper percentile  # noqa: E501

        :return: The upper_percent of this QueryIndicatorStatisticOutput.  # noqa: E501
        :rtype: float
        """
        return self._upper_percent

    @upper_percent.setter
    def upper_percent(self, upper_percent):
        """Sets the upper_percent of this QueryIndicatorStatisticOutput.

        上百分位 upper percentile  # noqa: E501

        :param upper_percent: The upper_percent of this QueryIndicatorStatisticOutput.  # noqa: E501
        :type: float
        """

        self._upper_percent = upper_percent

    @property
    def lower_percent(self):
        """Gets the lower_percent of this QueryIndicatorStatisticOutput.  # noqa: E501

        下百分位 lower percentile  # noqa: E501

        :return: The lower_percent of this QueryIndicatorStatisticOutput.  # noqa: E501
        :rtype: float
        """
        return self._lower_percent

    @lower_percent.setter
    def lower_percent(self, lower_percent):
        """Sets the lower_percent of this QueryIndicatorStatisticOutput.

        下百分位 lower percentile  # noqa: E501

        :param lower_percent: The lower_percent of this QueryIndicatorStatisticOutput.  # noqa: E501
        :type: float
        """

        self._lower_percent = lower_percent

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, QueryIndicatorStatisticOutput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, QueryIndicatorStatisticOutput):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    wd-domain-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_wd_domain_service.configuration import Configuration


class DeviceDetailInfo(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'name': 'str',
        'label': 'str',
        'description': 'str',
        'group': 'str',
        'location': 'str',
        'type': 'str',
        'device_indicators': 'list[DeviceIndicatorInfo]'
    }

    attribute_map = {
        'id': 'id',
        'name': 'name',
        'label': 'label',
        'description': 'description',
        'group': 'group',
        'location': 'location',
        'type': 'type',
        'device_indicators': 'deviceIndicators'
    }

    def __init__(self, id=None, name=None, label=None, description=None, group=None, location=None, type=None, device_indicators=None, local_vars_configuration=None):  # noqa: E501
        """DeviceDetailInfo - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._name = None
        self._label = None
        self._description = None
        self._group = None
        self._location = None
        self._type = None
        self._device_indicators = None
        self.discriminator = None

        if id is not None:
            self.id = id
        self.name = name
        self.label = label
        self.description = description
        self.group = group
        self.location = location
        self.type = type
        self.device_indicators = device_indicators

    @property
    def id(self):
        """Gets the id of this DeviceDetailInfo.  # noqa: E501

        设备id  # noqa: E501

        :return: The id of this DeviceDetailInfo.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this DeviceDetailInfo.

        设备id  # noqa: E501

        :param id: The id of this DeviceDetailInfo.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def name(self):
        """Gets the name of this DeviceDetailInfo.  # noqa: E501

        设备名  # noqa: E501

        :return: The name of this DeviceDetailInfo.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this DeviceDetailInfo.

        设备名  # noqa: E501

        :param name: The name of this DeviceDetailInfo.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def label(self):
        """Gets the label of this DeviceDetailInfo.  # noqa: E501


        :return: The label of this DeviceDetailInfo.  # noqa: E501
        :rtype: str
        """
        return self._label

    @label.setter
    def label(self, label):
        """Sets the label of this DeviceDetailInfo.


        :param label: The label of this DeviceDetailInfo.  # noqa: E501
        :type: str
        """

        self._label = label

    @property
    def description(self):
        """Gets the description of this DeviceDetailInfo.  # noqa: E501


        :return: The description of this DeviceDetailInfo.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this DeviceDetailInfo.


        :param description: The description of this DeviceDetailInfo.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def group(self):
        """Gets the group of this DeviceDetailInfo.  # noqa: E501

        设备分组  # noqa: E501

        :return: The group of this DeviceDetailInfo.  # noqa: E501
        :rtype: str
        """
        return self._group

    @group.setter
    def group(self, group):
        """Sets the group of this DeviceDetailInfo.

        设备分组  # noqa: E501

        :param group: The group of this DeviceDetailInfo.  # noqa: E501
        :type: str
        """

        self._group = group

    @property
    def location(self):
        """Gets the location of this DeviceDetailInfo.  # noqa: E501

        位置  # noqa: E501

        :return: The location of this DeviceDetailInfo.  # noqa: E501
        :rtype: str
        """
        return self._location

    @location.setter
    def location(self, location):
        """Sets the location of this DeviceDetailInfo.

        位置  # noqa: E501

        :param location: The location of this DeviceDetailInfo.  # noqa: E501
        :type: str
        """

        self._location = location

    @property
    def type(self):
        """Gets the type of this DeviceDetailInfo.  # noqa: E501

        设备类型  # noqa: E501

        :return: The type of this DeviceDetailInfo.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this DeviceDetailInfo.

        设备类型  # noqa: E501

        :param type: The type of this DeviceDetailInfo.  # noqa: E501
        :type: str
        """

        self._type = type

    @property
    def device_indicators(self):
        """Gets the device_indicators of this DeviceDetailInfo.  # noqa: E501

        设备指标列表  # noqa: E501

        :return: The device_indicators of this DeviceDetailInfo.  # noqa: E501
        :rtype: list[DeviceIndicatorInfo]
        """
        return self._device_indicators

    @device_indicators.setter
    def device_indicators(self, device_indicators):
        """Sets the device_indicators of this DeviceDetailInfo.

        设备指标列表  # noqa: E501

        :param device_indicators: The device_indicators of this DeviceDetailInfo.  # noqa: E501
        :type: list[DeviceIndicatorInfo]
        """

        self._device_indicators = device_indicators

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DeviceDetailInfo):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DeviceDetailInfo):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    identity-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_identity_service.configuration import Configuration


class ButtonPerUnderMenuOutput(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'menu_id': 'str',
        'menu_label': 'str',
        'button_pers': 'list[ButtonPer]'
    }

    attribute_map = {
        'menu_id': 'menuId',
        'menu_label': 'menuLabel',
        'button_pers': 'buttonPers'
    }

    def __init__(self, menu_id=None, menu_label=None, button_pers=None, local_vars_configuration=None):  # noqa: E501
        """ButtonPerUnderMenuOutput - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._menu_id = None
        self._menu_label = None
        self._button_pers = None
        self.discriminator = None

        if menu_id is not None:
            self.menu_id = menu_id
        self.menu_label = menu_label
        self.button_pers = button_pers

    @property
    def menu_id(self):
        """Gets the menu_id of this ButtonPerUnderMenuOutput.  # noqa: E501

        菜单Id memu id  # noqa: E501

        :return: The menu_id of this ButtonPerUnderMenuOutput.  # noqa: E501
        :rtype: str
        """
        return self._menu_id

    @menu_id.setter
    def menu_id(self, menu_id):
        """Sets the menu_id of this ButtonPerUnderMenuOutput.

        菜单Id memu id  # noqa: E501

        :param menu_id: The menu_id of this ButtonPerUnderMenuOutput.  # noqa: E501
        :type: str
        """

        self._menu_id = menu_id

    @property
    def menu_label(self):
        """Gets the menu_label of this ButtonPerUnderMenuOutput.  # noqa: E501

        菜单名称 menu label  # noqa: E501

        :return: The menu_label of this ButtonPerUnderMenuOutput.  # noqa: E501
        :rtype: str
        """
        return self._menu_label

    @menu_label.setter
    def menu_label(self, menu_label):
        """Sets the menu_label of this ButtonPerUnderMenuOutput.

        菜单名称 menu label  # noqa: E501

        :param menu_label: The menu_label of this ButtonPerUnderMenuOutput.  # noqa: E501
        :type: str
        """

        self._menu_label = menu_label

    @property
    def button_pers(self):
        """Gets the button_pers of this ButtonPerUnderMenuOutput.  # noqa: E501

        菜单下的按钮权限 button permissions of the menu  # noqa: E501

        :return: The button_pers of this ButtonPerUnderMenuOutput.  # noqa: E501
        :rtype: list[ButtonPer]
        """
        return self._button_pers

    @button_pers.setter
    def button_pers(self, button_pers):
        """Sets the button_pers of this ButtonPerUnderMenuOutput.

        菜单下的按钮权限 button permissions of the menu  # noqa: E501

        :param button_pers: The button_pers of this ButtonPerUnderMenuOutput.  # noqa: E501
        :type: list[ButtonPer]
        """

        self._button_pers = button_pers

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ButtonPerUnderMenuOutput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ButtonPerUnderMenuOutput):
            return True

        return self.to_dict() != other.to_dict()



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from dhicn_zyws_service.api.algorithm_api import AlgorithmApi
from dhicn_zyws_service.api.auto_run_result_api import AutoRunResultApi
from dhicn_zyws_service.api.calculate_orifice_height_api import CalculateOrificeHeightApi
from dhicn_zyws_service.api.configuration_api import ConfigurationApi
from dhicn_zyws_service.api.control_api import ControlApi
from dhicn_zyws_service.api.dam_gate_api import DamGateApi
from dhicn_zyws_service.api.inflow_api import InflowApi
from dhicn_zyws_service.api.model_result_api import ModelResultApi
from dhicn_zyws_service.api.orifice_opened_result_api import OrificeOpenedResultApi
from dhicn_zyws_service.api.scenario_api import ScenarioApi
from dhicn_zyws_service.api.schdule_suggestion_api import SchduleSuggestionApi
from dhicn_zyws_service.api.schedule_analysis_api import ScheduleAnalysisApi
from dhicn_zyws_service.api.system_setting_api import SystemSettingApi
from dhicn_zyws_service.api.timeseries_api import TimeseriesApi
from dhicn_zyws_service.api.urban_water_distribution_algorithm_api import UrbanWaterDistributionAlgorithmApi
from dhicn_zyws_service.api.water_delivery_principle_api import WaterDeliveryPrincipleApi



# coding: utf-8

"""
    wwtp-paas-main-bus-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_wwtp_data_bus_service.configuration import Configuration


class DeviceMaintenanceOutput(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'online_point': 'str',
        'point_code': 'str',
        'time': 'datetime',
        'location': 'str',
        'status': 'str',
        'message': 'str',
        'label': 'str',
        'tag': 'str',
        'grade': 'int'
    }

    attribute_map = {
        'online_point': 'onlinePoint',
        'point_code': 'pointCode',
        'time': 'time',
        'location': 'location',
        'status': 'status',
        'message': 'message',
        'label': 'label',
        'tag': 'tag',
        'grade': 'grade'
    }

    def __init__(self, online_point=None, point_code=None, time=None, location=None, status=None, message=None, label=None, tag=None, grade=None, local_vars_configuration=None):  # noqa: E501
        """DeviceMaintenanceOutput - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._online_point = None
        self._point_code = None
        self._time = None
        self._location = None
        self._status = None
        self._message = None
        self._label = None
        self._tag = None
        self._grade = None
        self.discriminator = None

        self.online_point = online_point
        self.point_code = point_code
        if time is not None:
            self.time = time
        self.location = location
        self.status = status
        self.message = message
        self.label = label
        self.tag = tag
        if grade is not None:
            self.grade = grade

    @property
    def online_point(self):
        """Gets the online_point of this DeviceMaintenanceOutput.  # noqa: E501

        在线点位名称 online point name  # noqa: E501

        :return: The online_point of this DeviceMaintenanceOutput.  # noqa: E501
        :rtype: str
        """
        return self._online_point

    @online_point.setter
    def online_point(self, online_point):
        """Sets the online_point of this DeviceMaintenanceOutput.

        在线点位名称 online point name  # noqa: E501

        :param online_point: The online_point of this DeviceMaintenanceOutput.  # noqa: E501
        :type: str
        """

        self._online_point = online_point

    @property
    def point_code(self):
        """Gets the point_code of this DeviceMaintenanceOutput.  # noqa: E501

        在线点位代码 online point code  # noqa: E501

        :return: The point_code of this DeviceMaintenanceOutput.  # noqa: E501
        :rtype: str
        """
        return self._point_code

    @point_code.setter
    def point_code(self, point_code):
        """Sets the point_code of this DeviceMaintenanceOutput.

        在线点位代码 online point code  # noqa: E501

        :param point_code: The point_code of this DeviceMaintenanceOutput.  # noqa: E501
        :type: str
        """

        self._point_code = point_code

    @property
    def time(self):
        """Gets the time of this DeviceMaintenanceOutput.  # noqa: E501

        时间 time  # noqa: E501

        :return: The time of this DeviceMaintenanceOutput.  # noqa: E501
        :rtype: datetime
        """
        return self._time

    @time.setter
    def time(self, time):
        """Sets the time of this DeviceMaintenanceOutput.

        时间 time  # noqa: E501

        :param time: The time of this DeviceMaintenanceOutput.  # noqa: E501
        :type: datetime
        """

        self._time = time

    @property
    def location(self):
        """Gets the location of this DeviceMaintenanceOutput.  # noqa: E501

        位置 location  # noqa: E501

        :return: The location of this DeviceMaintenanceOutput.  # noqa: E501
        :rtype: str
        """
        return self._location

    @location.setter
    def location(self, location):
        """Sets the location of this DeviceMaintenanceOutput.

        位置 location  # noqa: E501

        :param location: The location of this DeviceMaintenanceOutput.  # noqa: E501
        :type: str
        """

        self._location = location

    @property
    def status(self):
        """Gets the status of this DeviceMaintenanceOutput.  # noqa: E501

        维护预警状态 maintenance alarm status  # noqa: E501

        :return: The status of this DeviceMaintenanceOutput.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this DeviceMaintenanceOutput.

        维护预警状态 maintenance alarm status  # noqa: E501

        :param status: The status of this DeviceMaintenanceOutput.  # noqa: E501
        :type: str
        """

        self._status = status

    @property
    def message(self):
        """Gets the message of this DeviceMaintenanceOutput.  # noqa: E501

        维护预警信息 maintenance alarm message  # noqa: E501

        :return: The message of this DeviceMaintenanceOutput.  # noqa: E501
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """Sets the message of this DeviceMaintenanceOutput.

        维护预警信息 maintenance alarm message  # noqa: E501

        :param message: The message of this DeviceMaintenanceOutput.  # noqa: E501
        :type: str
        """

        self._message = message

    @property
    def label(self):
        """Gets the label of this DeviceMaintenanceOutput.  # noqa: E501

        设备状态标签 device status label  # noqa: E501

        :return: The label of this DeviceMaintenanceOutput.  # noqa: E501
        :rtype: str
        """
        return self._label

    @label.setter
    def label(self, label):
        """Sets the label of this DeviceMaintenanceOutput.

        设备状态标签 device status label  # noqa: E501

        :param label: The label of this DeviceMaintenanceOutput.  # noqa: E501
        :type: str
        """

        self._label = label

    @property
    def tag(self):
        """Gets the tag of this DeviceMaintenanceOutput.  # noqa: E501

        清洗标签 data clean tag  # noqa: E501

        :return: The tag of this DeviceMaintenanceOutput.  # noqa: E501
        :rtype: str
        """
        return self._tag

    @tag.setter
    def tag(self, tag):
        """Sets the tag of this DeviceMaintenanceOutput.

        清洗标签 data clean tag  # noqa: E501

        :param tag: The tag of this DeviceMaintenanceOutput.  # noqa: E501
        :type: str
        """

        self._tag = tag

    @property
    def grade(self):
        """Gets the grade of this DeviceMaintenanceOutput.  # noqa: E501


        :return: The grade of this DeviceMaintenanceOutput.  # noqa: E501
        :rtype: int
        """
        return self._grade

    @grade.setter
    def grade(self, grade):
        """Sets the grade of this DeviceMaintenanceOutput.


        :param grade: The grade of this DeviceMaintenanceOutput.  # noqa: E501
        :type: int
        """
        allowed_values = [0, 1, 2]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and grade not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `grade` ({0}), must be one of {1}"  # noqa: E501
                .format(grade, allowed_values)
            )

        self._grade = grade

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DeviceMaintenanceOutput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DeviceMaintenanceOutput):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    scenario-compute-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_scenario_compute_service.configuration import Configuration


class DhiDssScenarioComputeDaprServicesDtosRunModelInfo(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'model_type': 'str',
        'scenario_id': 'str',
        'tenant_id': 'str',
        'template_scenario_id': 'str',
        'business_type': 'int',
        'library_type': 'int'
    }

    attribute_map = {
        'model_type': 'modelType',
        'scenario_id': 'scenarioId',
        'tenant_id': 'tenantId',
        'template_scenario_id': 'templateScenarioId',
        'business_type': 'businessType',
        'library_type': 'libraryType'
    }

    def __init__(self, model_type=None, scenario_id=None, tenant_id=None, template_scenario_id=None, business_type=None, library_type=None, local_vars_configuration=None):  # noqa: E501
        """DhiDssScenarioComputeDaprServicesDtosRunModelInfo - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._model_type = None
        self._scenario_id = None
        self._tenant_id = None
        self._template_scenario_id = None
        self._business_type = None
        self._library_type = None
        self.discriminator = None

        self.model_type = model_type
        self.scenario_id = scenario_id
        self.tenant_id = tenant_id
        self.template_scenario_id = template_scenario_id
        if business_type is not None:
            self.business_type = business_type
        if library_type is not None:
            self.library_type = library_type

    @property
    def model_type(self):
        """Gets the model_type of this DhiDssScenarioComputeDaprServicesDtosRunModelInfo.  # noqa: E501


        :return: The model_type of this DhiDssScenarioComputeDaprServicesDtosRunModelInfo.  # noqa: E501
        :rtype: str
        """
        return self._model_type

    @model_type.setter
    def model_type(self, model_type):
        """Sets the model_type of this DhiDssScenarioComputeDaprServicesDtosRunModelInfo.


        :param model_type: The model_type of this DhiDssScenarioComputeDaprServicesDtosRunModelInfo.  # noqa: E501
        :type: str
        """

        self._model_type = model_type

    @property
    def scenario_id(self):
        """Gets the scenario_id of this DhiDssScenarioComputeDaprServicesDtosRunModelInfo.  # noqa: E501


        :return: The scenario_id of this DhiDssScenarioComputeDaprServicesDtosRunModelInfo.  # noqa: E501
        :rtype: str
        """
        return self._scenario_id

    @scenario_id.setter
    def scenario_id(self, scenario_id):
        """Sets the scenario_id of this DhiDssScenarioComputeDaprServicesDtosRunModelInfo.


        :param scenario_id: The scenario_id of this DhiDssScenarioComputeDaprServicesDtosRunModelInfo.  # noqa: E501
        :type: str
        """

        self._scenario_id = scenario_id

    @property
    def tenant_id(self):
        """Gets the tenant_id of this DhiDssScenarioComputeDaprServicesDtosRunModelInfo.  # noqa: E501


        :return: The tenant_id of this DhiDssScenarioComputeDaprServicesDtosRunModelInfo.  # noqa: E501
        :rtype: str
        """
        return self._tenant_id

    @tenant_id.setter
    def tenant_id(self, tenant_id):
        """Sets the tenant_id of this DhiDssScenarioComputeDaprServicesDtosRunModelInfo.


        :param tenant_id: The tenant_id of this DhiDssScenarioComputeDaprServicesDtosRunModelInfo.  # noqa: E501
        :type: str
        """

        self._tenant_id = tenant_id

    @property
    def template_scenario_id(self):
        """Gets the template_scenario_id of this DhiDssScenarioComputeDaprServicesDtosRunModelInfo.  # noqa: E501


        :return: The template_scenario_id of this DhiDssScenarioComputeDaprServicesDtosRunModelInfo.  # noqa: E501
        :rtype: str
        """
        return self._template_scenario_id

    @template_scenario_id.setter
    def template_scenario_id(self, template_scenario_id):
        """Sets the template_scenario_id of this DhiDssScenarioComputeDaprServicesDtosRunModelInfo.


        :param template_scenario_id: The template_scenario_id of this DhiDssScenarioComputeDaprServicesDtosRunModelInfo.  # noqa: E501
        :type: str
        """

        self._template_scenario_id = template_scenario_id

    @property
    def business_type(self):
        """Gets the business_type of this DhiDssScenarioComputeDaprServicesDtosRunModelInfo.  # noqa: E501

        0-Undefined(Undefined) 1-WaterEnvironment(Water environment) 2-UrbanFlooding(Urban flooding) 3-UrbanWD(Water distribution) 4-RiverFlood(River flood)   # noqa: E501

        :return: The business_type of this DhiDssScenarioComputeDaprServicesDtosRunModelInfo.  # noqa: E501
        :rtype: int
        """
        return self._business_type

    @business_type.setter
    def business_type(self, business_type):
        """Sets the business_type of this DhiDssScenarioComputeDaprServicesDtosRunModelInfo.

        0-Undefined(Undefined) 1-WaterEnvironment(Water environment) 2-UrbanFlooding(Urban flooding) 3-UrbanWD(Water distribution) 4-RiverFlood(River flood)   # noqa: E501

        :param business_type: The business_type of this DhiDssScenarioComputeDaprServicesDtosRunModelInfo.  # noqa: E501
        :type: int
        """
        allowed_values = [0, 1, 2, 3, 4]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and business_type not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `business_type` ({0}), must be one of {1}"  # noqa: E501
                .format(business_type, allowed_values)
            )

        self._business_type = business_type

    @property
    def library_type(self):
        """Gets the library_type of this DhiDssScenarioComputeDaprServicesDtosRunModelInfo.  # noqa: E501

        0-Undefined(Undefined) 1-AutoForecast(Auto forecast library) 2-ManualForecast(Manual forecast library) 3-Forecast(Forecast library) 4-Schedule(Schedule library) 5-Experience(Experience library) 6-ScenarioSimulation(Scenario simulation library) 7-WQAccident(Water quality accident library) 8-OnlineHD(WD Hydrodynamic library) 9-WaterHammer(WD water hammer library) 10-Filling(WD pipe filling library) 11-PipeBurst(WD pipe burst library) 12-WQResponse(Water quality accident response library) 13-Planning(WD planning library) 14-Flushing(WD flushing library) 15-OnlineWQAccident(Online Water quality accident library) 16-CloseValve(WD close valve library)   # noqa: E501

        :return: The library_type of this DhiDssScenarioComputeDaprServicesDtosRunModelInfo.  # noqa: E501
        :rtype: int
        """
        return self._library_type

    @library_type.setter
    def library_type(self, library_type):
        """Sets the library_type of this DhiDssScenarioComputeDaprServicesDtosRunModelInfo.

        0-Undefined(Undefined) 1-AutoForecast(Auto forecast library) 2-ManualForecast(Manual forecast library) 3-Forecast(Forecast library) 4-Schedule(Schedule library) 5-Experience(Experience library) 6-ScenarioSimulation(Scenario simulation library) 7-WQAccident(Water quality accident library) 8-OnlineHD(WD Hydrodynamic library) 9-WaterHammer(WD water hammer library) 10-Filling(WD pipe filling library) 11-PipeBurst(WD pipe burst library) 12-WQResponse(Water quality accident response library) 13-Planning(WD planning library) 14-Flushing(WD flushing library) 15-OnlineWQAccident(Online Water quality accident library) 16-CloseValve(WD close valve library)   # noqa: E501

        :param library_type: The library_type of this DhiDssScenarioComputeDaprServicesDtosRunModelInfo.  # noqa: E501
        :type: int
        """
        allowed_values = [0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and library_type not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `library_type` ({0}), must be one of {1}"  # noqa: E501
                .format(library_type, allowed_values)
            )

        self._library_type = library_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DhiDssScenarioComputeDaprServicesDtosRunModelInfo):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DhiDssScenarioComputeDaprServicesDtosRunModelInfo):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    identity-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_identity_service.configuration import Configuration


class Data(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'product_line': 'str',
        'raise_ratio': 'float',
        'cost_datas': 'list[CostData]'
    }

    attribute_map = {
        'product_line': 'productLine',
        'raise_ratio': 'raiseRatio',
        'cost_datas': 'costDatas'
    }

    def __init__(self, product_line=None, raise_ratio=None, cost_datas=None, local_vars_configuration=None):  # noqa: E501
        """Data - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._product_line = None
        self._raise_ratio = None
        self._cost_datas = None
        self.discriminator = None

        self.product_line = product_line
        self.raise_ratio = raise_ratio
        self.cost_datas = cost_datas

    @property
    def product_line(self):
        """Gets the product_line of this Data.  # noqa: E501

        工艺线代码 product line code  # noqa: E501

        :return: The product_line of this Data.  # noqa: E501
        :rtype: str
        """
        return self._product_line

    @product_line.setter
    def product_line(self, product_line):
        """Sets the product_line of this Data.

        工艺线代码 product line code  # noqa: E501

        :param product_line: The product_line of this Data.  # noqa: E501
        :type: str
        """

        self._product_line = product_line

    @property
    def raise_ratio(self):
        """Gets the raise_ratio of this Data.  # noqa: E501

        与上一周对比的增长率，若为负数，则表示降低了 raise ratio compared to last week  # noqa: E501

        :return: The raise_ratio of this Data.  # noqa: E501
        :rtype: float
        """
        return self._raise_ratio

    @raise_ratio.setter
    def raise_ratio(self, raise_ratio):
        """Sets the raise_ratio of this Data.

        与上一周对比的增长率，若为负数，则表示降低了 raise ratio compared to last week  # noqa: E501

        :param raise_ratio: The raise_ratio of this Data.  # noqa: E501
        :type: float
        """

        self._raise_ratio = raise_ratio

    @property
    def cost_datas(self):
        """Gets the cost_datas of this Data.  # noqa: E501

        一周中每天的吨水药耗 dosage cost per ton water of each day  # noqa: E501

        :return: The cost_datas of this Data.  # noqa: E501
        :rtype: list[CostData]
        """
        return self._cost_datas

    @cost_datas.setter
    def cost_datas(self, cost_datas):
        """Sets the cost_datas of this Data.

        一周中每天的吨水药耗 dosage cost per ton water of each day  # noqa: E501

        :param cost_datas: The cost_datas of this Data.  # noqa: E501
        :type: list[CostData]
        """

        self._cost_datas = cost_datas

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Data):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Data):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

# flake8: noqa
"""
    accident-manager-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

# import models into model package
from dhicn_accident_management_service.models.accident_detail_info import AccidentDetailInfo
from dhicn_accident_management_service.models.accident_detail_input import AccidentDetailInput
from dhicn_accident_management_service.models.accident_info import AccidentInfo
from dhicn_accident_management_service.models.accident_level_enum import AccidentLevelEnum
from dhicn_accident_management_service.models.accident_type_enum import AccidentTypeEnum
from dhicn_accident_management_service.models.add_accident_input import AddAccidentInput
from dhicn_accident_management_service.models.add_component_input import AddComponentInput
from dhicn_accident_management_service.models.add_component_key_input import AddComponentKeyInput
from dhicn_accident_management_service.models.add_component_value_input import AddComponentValueInput
from dhicn_accident_management_service.models.add_event_input import AddEventInput
from dhicn_accident_management_service.models.add_scene_input import AddSceneInput
from dhicn_accident_management_service.models.add_ts_input import AddTsInput
from dhicn_accident_management_service.models.business_type_enum import BusinessTypeEnum
from dhicn_accident_management_service.models.component_detail_info import ComponentDetailInfo
from dhicn_accident_management_service.models.component_detail_input import ComponentDetailInput
from dhicn_accident_management_service.models.component_info import ComponentInfo
from dhicn_accident_management_service.models.component_key_info import ComponentKeyInfo
from dhicn_accident_management_service.models.component_value_info import ComponentValueInfo
from dhicn_accident_management_service.models.discharge_type_enum import DischargeTypeEnum
from dhicn_accident_management_service.models.event_detail_info import EventDetailInfo
from dhicn_accident_management_service.models.event_detail_input import EventDetailInput
from dhicn_accident_management_service.models.event_info import EventInfo
from dhicn_accident_management_service.models.remote_service_error_info import RemoteServiceErrorInfo
from dhicn_accident_management_service.models.remote_service_error_response import RemoteServiceErrorResponse
from dhicn_accident_management_service.models.remote_service_validation_error_info import RemoteServiceValidationErrorInfo
from dhicn_accident_management_service.models.scene_detail_info import SceneDetailInfo
from dhicn_accident_management_service.models.scene_detail_input import SceneDetailInput
from dhicn_accident_management_service.models.scene_info import SceneInfo
from dhicn_accident_management_service.models.ts_struct import TsStruct
from dhicn_accident_management_service.models.update_accident_input import UpdateAccidentInput
from dhicn_accident_management_service.models.update_component_input import UpdateComponentInput
from dhicn_accident_management_service.models.update_component_value_input import UpdateComponentValueInput
from dhicn_accident_management_service.models.update_event_input import UpdateEventInput
from dhicn_accident_management_service.models.update_scene_input import UpdateSceneInput
from dhicn_accident_management_service.models.value_info import ValueInfo
from dhicn_accident_management_service.models.value_type_enum import ValueTypeEnum



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from dhicn_model_configuration_service.api.init_project_api import InitProjectApi
from dhicn_model_configuration_service.api.legend_api import LegendApi
from dhicn_model_configuration_service.api.model_template_api import ModelTemplateApi
from dhicn_model_configuration_service.api.scenario_api import ScenarioApi



# coding: utf-8

"""
    document-manager-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_document_service.configuration import Configuration


class HttpRequestMessage(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'version': 'Version',
        'version_policy': 'HttpVersionPolicy',
        'content': 'HttpContent',
        'method': 'HttpMethod',
        'request_uri': 'str',
        'headers': 'list[StringStringIEnumerableKeyValuePair]',
        'properties': 'dict(str, str)',
        'options': 'dict(str, str)'
    }

    attribute_map = {
        'version': 'version',
        'version_policy': 'versionPolicy',
        'content': 'content',
        'method': 'method',
        'request_uri': 'requestUri',
        'headers': 'headers',
        'properties': 'properties',
        'options': 'options'
    }

    def __init__(self, version=None, version_policy=None, content=None, method=None, request_uri=None, headers=None, properties=None, options=None, local_vars_configuration=None):  # noqa: E501
        """HttpRequestMessage - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._version = None
        self._version_policy = None
        self._content = None
        self._method = None
        self._request_uri = None
        self._headers = None
        self._properties = None
        self._options = None
        self.discriminator = None

        if version is not None:
            self.version = version
        if version_policy is not None:
            self.version_policy = version_policy
        if content is not None:
            self.content = content
        if method is not None:
            self.method = method
        self.request_uri = request_uri
        self.headers = headers
        self.properties = properties
        self.options = options

    @property
    def version(self):
        """Gets the version of this HttpRequestMessage.  # noqa: E501


        :return: The version of this HttpRequestMessage.  # noqa: E501
        :rtype: Version
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this HttpRequestMessage.


        :param version: The version of this HttpRequestMessage.  # noqa: E501
        :type: Version
        """

        self._version = version

    @property
    def version_policy(self):
        """Gets the version_policy of this HttpRequestMessage.  # noqa: E501


        :return: The version_policy of this HttpRequestMessage.  # noqa: E501
        :rtype: HttpVersionPolicy
        """
        return self._version_policy

    @version_policy.setter
    def version_policy(self, version_policy):
        """Sets the version_policy of this HttpRequestMessage.


        :param version_policy: The version_policy of this HttpRequestMessage.  # noqa: E501
        :type: HttpVersionPolicy
        """

        self._version_policy = version_policy

    @property
    def content(self):
        """Gets the content of this HttpRequestMessage.  # noqa: E501


        :return: The content of this HttpRequestMessage.  # noqa: E501
        :rtype: HttpContent
        """
        return self._content

    @content.setter
    def content(self, content):
        """Sets the content of this HttpRequestMessage.


        :param content: The content of this HttpRequestMessage.  # noqa: E501
        :type: HttpContent
        """

        self._content = content

    @property
    def method(self):
        """Gets the method of this HttpRequestMessage.  # noqa: E501


        :return: The method of this HttpRequestMessage.  # noqa: E501
        :rtype: HttpMethod
        """
        return self._method

    @method.setter
    def method(self, method):
        """Sets the method of this HttpRequestMessage.


        :param method: The method of this HttpRequestMessage.  # noqa: E501
        :type: HttpMethod
        """

        self._method = method

    @property
    def request_uri(self):
        """Gets the request_uri of this HttpRequestMessage.  # noqa: E501


        :return: The request_uri of this HttpRequestMessage.  # noqa: E501
        :rtype: str
        """
        return self._request_uri

    @request_uri.setter
    def request_uri(self, request_uri):
        """Sets the request_uri of this HttpRequestMessage.


        :param request_uri: The request_uri of this HttpRequestMessage.  # noqa: E501
        :type: str
        """

        self._request_uri = request_uri

    @property
    def headers(self):
        """Gets the headers of this HttpRequestMessage.  # noqa: E501


        :return: The headers of this HttpRequestMessage.  # noqa: E501
        :rtype: list[StringStringIEnumerableKeyValuePair]
        """
        return self._headers

    @headers.setter
    def headers(self, headers):
        """Sets the headers of this HttpRequestMessage.


        :param headers: The headers of this HttpRequestMessage.  # noqa: E501
        :type: list[StringStringIEnumerableKeyValuePair]
        """

        self._headers = headers

    @property
    def properties(self):
        """Gets the properties of this HttpRequestMessage.  # noqa: E501


        :return: The properties of this HttpRequestMessage.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._properties

    @properties.setter
    def properties(self, properties):
        """Sets the properties of this HttpRequestMessage.


        :param properties: The properties of this HttpRequestMessage.  # noqa: E501
        :type: dict(str, str)
        """

        self._properties = properties

    @property
    def options(self):
        """Gets the options of this HttpRequestMessage.  # noqa: E501


        :return: The options of this HttpRequestMessage.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._options

    @options.setter
    def options(self, options):
        """Sets the options of this HttpRequestMessage.


        :param options: The options of this HttpRequestMessage.  # noqa: E501
        :type: dict(str, str)
        """

        self._options = options

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, HttpRequestMessage):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, HttpRequestMessage):
            return True

        return self.to_dict() != other.to_dict()
